==> haskell-cairo-0.13.12.0-19.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   cairo
version:                0.13.12.0
visibility:             public
id:                     cairo-0.13.12.0-BiwVnSgGXm15PnXZRv298w
key:                    cairo-0.13.12.0-BiwVnSgGXm15PnXZRv298w
license:                BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    3b92f98ec9f3098f55cc97b5c772e714
exposed:                True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:            /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-cairo
hs-libraries:           HScairo-0.13.12.0-BiwVnSgGXm15PnXZRv298w
extra-libraries:        cairo png16 z
extra-libraries-static:
    cairo m dl fontconfig m expat m freetype dl bz2 brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include /usr/include/cairo /usr/include/freetype2
    /usr/include/pixman-1 /usr/include/libpng16

depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 mtl-2.3.1
    text-2.0.2 utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:     /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:           /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cairo-0.13.12.0-20-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   cairo
version:                0.13.12.0
visibility:             public
id:                     cairo-0.13.12.0-3aBf3J5x54XF9reOVk3EKF
key:                    cairo-0.13.12.0-3aBf3J5x54XF9reOVk3EKF
license:                BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    37efafb8fce8c4e14c9428a03b9fe2f4
exposed:                True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:            /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/cairo-0.13.12.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-cairo
hs-libraries:           HScairo-0.13.12.0-3aBf3J5x54XF9reOVk3EKF
extra-libraries:        cairo png16 z
extra-libraries-static:
    cairo m dl fontconfig m expat m freetype dl bz2 brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include /usr/include/cairo /usr/include/freetype2
    /usr/include/pixman-1 /usr/include/libpng16

depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 mtl-2.3.1
    text-2.0.2 utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:     /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:           /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
